@@ -10,8 +10,5 @@ If you want to extend `logrun`, you'll want to use the functionalities provided
 `logrun.utils`.
 """
 
-from logrun import utils
-from logrun import internals
 
-
-__version__ = '0.1.1'
+__version__ = '0.1.2'
